/**
 * $Header: /cvs/urlrewrite/src/java/org/tuckey/web/filters/urlrewrite/UrlRewriteDocTask.java,v 1.3 2004/05/25 07:37:37 ptuckey Exp $
 * $Revision: 1.3 $
 * $Date: 2004/05/25 07:37:37 $
 */
package org.tuckey.web.filters.urlrewrite;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.tuckey.utils.StringUtils;

import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;


/**
 * Used for javadoc style output of conf file.
 * todo: make it output html
 *
 * @author Paul Tuckey
 * @version $Revision: 1.3 $ $Date: 2004/05/25 07:37:37 $
 */
public class UrlRewriteDocTask extends Task {

    Conf conf;

    private String conffile = UrlRewriteFilter.DEFAULT_WEB_CONF_PATH;

    private static final String RES_PATH = "/org/tuckey/web/filters/urlrewrite/doc/";
    private String destdir = "reports/urlrewrite";

    private StringBuffer buffer = new StringBuffer();

    public void execute() throws BuildException {
        try {
            Conf conf = new Conf(new FileInputStream(conffile), conffile);
            conf.initialise();

            if (!conf.isOk()) {
                throw new BuildException("conf is not ok");
            }
            log("loaded fine with " + conf.getRules().size() + " rules");

            File reportDir = new File(destdir);
            if (!reportDir.exists()) {
                throw new BuildException("destdir does not exist (" + destdir + ")");
            }
            copyResourceToDisk("doc.css", reportDir);

            File reportFile = new File(reportDir.getPath() + File.separator + "index.html");
            if (reportFile.exists()) {
                reportFile.delete();
            }
            FileWriter writer;
            writer = new FileWriter(reportFile);
            SimpleDateFormat s = new SimpleDateFormat();

            println("<html>");
            println("<head>");
            println("<title>UrlRewriteFilter configuration overview for " + conf.getFileName() + "</title>");
            println("<style> @import \"doc.css\"; </style>");
            println("<body>");
            println("<h1><a href=\"http://tuckey.org/urlrewrite/\">UrlRewriteFilter</a> " +
                    UrlRewriteFilter.VERSION + " configuration overview " +
                    "(generated " + s.format(new Date()) + ")</h1>");
            println("<hr />");

            final List rules = conf.getRules();
            if (rules.size() > 0) {
                println("<h2>Summary of " + conf.getFileName() + "</h2>");
                int conditionsCount = 0;
                for (int i = 0; i < rules.size(); i++) {
                    final Rule rule = (Rule) rules.get(i);
                    conditionsCount += rule.getConditions().size();
                }
                println("<p>In total there " +
                        (rules.size() == 1 ? "is 1 rule" : "are " + rules.size() + " rules") +
                        (conditionsCount > 0 ? " and " : "") +
                        (conditionsCount == 1 ? conditionsCount + " condtion" : "") +
                        (conditionsCount > 1 ? conditionsCount + " condtions" : "") +
                        " in the configuration file.</code></p>");
                for (int i = 0; i < rules.size(); i++) {
                    final Rule rule = (Rule) rules.get(i);
                    println("<h3>" + rule.getDisplayName() +
                            (rule.isEnabled() ? "" : " **DISABLED**") + "</h3>");
                    if (!StringUtils.isBlank(rule.getNote())) {
                        println("<dl><dd><p>" + StringUtils.nl2br(rule.getNote()) + "</p></dd></dl>");
                    }
                    print("<p>URL's matching <code>" + rule.getFrom() + "</code>");
                    if (!StringUtils.isBlank(rule.getTo())) {
                        print("will " +
                                ("forward".equals(rule.getToType()) ? "be <code>forwarded</code> to" : "") +
                                ("include".equals(rule.getToType()) ? "<code>include</code>" : "") +
                                ("redirect".equals(rule.getToType()) ? "be <code>redirected</code> to" : "") +
                                " <code>" + rule.getTo() + "</code>");
                    }
                    println(".</p>");
                    if (rule.getSetAttributes().size() > 0) {
                        List setAttributes = rule.getSetAttributes();
                        println("<p>Will set:</p>" +
                                "<ol>");
                        for (int j = 0; j < setAttributes.size(); j++) {
                            SetAttribute setAttribute = (SetAttribute) setAttributes.get(j);
                            println("<li>");
                            if ("response-header".equals(setAttribute.getType())) {
                                println("The <code>" + setAttribute.getName() + "</code> HTTP response header " +
                                        "to <code>" + setAttribute.getValue() + "</code>");

                            } else if ("request".equals(setAttribute.getType()) ||
                                    "session".equals(setAttribute.getType())) {
                                println("An attribute on the <code>" + setAttribute.getType() + "</code> object " +
                                        "called <code>" + setAttribute.getName() + "</code> " +
                                        "to the value " +
                                        "<code>" + setAttribute.getValue() + "</code>");
                            }
                            println("</li>");

                        }
                        println("</ol>");
                    }
                    if (rule.getConditions().size() > 0) {
                        List conditions = rule.getConditions();
                        println("<p>Given that the following condtion" +
                                (conditions.size() == 1 ? " is" : "s are") + " met.</p>" +
                                "<ol>");
                        for (int j = 0; j < conditions.size(); j++) {
                            Condition condition = (Condition) conditions.get(j);
                            println("<li>");
                            if ("header".equals(condition.getType())) {
                                println("The <code>" + condition.getName() + "</code> HTTP header " +
                                        ("notequal".equals(condition.getOperator()) ? "does NOT match" : "matches") + " " +
                                        "<code>" + condition.getValue() + "</code>");
                            } else {
                                println("<code>" + condition.getType() + "</code> is <code>" +
                                        ("greater".equals(condition.getOperator()) ? "greater than" : "") +
                                        ("less".equals(condition.getOperator()) ? "less than" : "") +
                                        ("equal".equals(condition.getOperator()) ? "equal to" : "") +
                                        ("notequal".equals(condition.getOperator()) ? "NOT equal to" : "") +
                                        ("greaterorequal".equals(condition.getOperator()) ? "is greater than or equal to" : "") +
                                        ("lessorequal".equals(condition.getOperator()) ? "is less than or equal to" : "") +
                                        " <code>" + condition.getValue() + "</code>");
                            }
                            if (j < conditions.size() - 1) {
                                println("<code>" + condition.getNext() + "</code>");
                            }
                            println("</li>");

                        }
                        println("</ol>");
                    }
                    if (!rule.isLast()) {
                        println("<p>Note, other rules will be proessed after this rule.</p>");
                    }
                    println("</p>");
                }
            } else {
                println("There are no rules defined in <code>" + conf.getFileName() + "</code>.");
            }

            println("<hr />");
            println("<br />");
            println("<br />");
            println("<br />");
            println("</body>");
            println("</html>");

            writer.write(buffer.toString());
            writer.close();

        } catch (FileNotFoundException e) {
            throw new BuildException(e);
        } catch (IOException e) {
            throw new BuildException(e);
        }


    }

    private void print(String s) {
        buffer.append(s);
    }

    private void println(String s) {
        buffer.append(s + "\n");
    }

    private void copyResourceToDisk(String resourceFile, File reportDir) throws IOException {
        File file = new File(reportDir.getPath() + File.separator + resourceFile);
        if (file.exists()) {
            file.delete();
        }
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        InputStream inputStream = UrlRewriteDocTask.class.getResourceAsStream(RES_PATH + resourceFile);
        if (inputStream == null) {
            throw new BuildException("unable to find " + resourceFile + " in classpath");
        }
        boolean done = false;

        while (!done) {
            int i = inputStream.read();
            if (i == -1) {
                done = true;
            } else {
                fileOutputStream.write((byte) i);
            }
        }
        inputStream.close();
        fileOutputStream.close();
        log("wrote " + resourceFile);
    }

    public void setConffile(String conffile) {
        this.conffile = conffile;
    }

    public void setDestdir(String destdir) {
        this.destdir = destdir;
    }


}
